summaryrefslogtreecommitdiff
path: root/src/jtag/jtag.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/jtag/jtag.h')
-rw-r--r--src/jtag/jtag.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/jtag/jtag.h b/src/jtag/jtag.h
index 16eb84dd..fca7c350 100644
--- a/src/jtag/jtag.h
+++ b/src/jtag/jtag.h
@@ -195,7 +195,8 @@ typedef struct jtag_interface_s
int (*register_commands)(struct command_context_s *cmd_ctx);
int (*init)(void);
int (*quit)(void);
- /* returns JTAG speed for KHz. */
+ /* returns JTAG maxium speed for KHz. 0=RTCK. The function returns
+ a failure if it can't support the KHz/RTCK. */
int (*khz)(int khz, int *jtag_speed);
} jtag_interface_t;